
## Installing

```
python3 -m pip install bongocat
```

## Usage

Create a folder and fill it with images of your cat pressing buttons.    
Rename each image to the button permutation you'd like it to appear for.  
```
cd /path/to/that/folder
```
Make sure there is a file named `-` (customizable) for neutral state.
```
bongocat
```
This will invoke the script. See [images][images] for examples of file sets.

[images]:https://github.com/Exahilosys/bongocat/tree/master/images
